==> nmds.1.2.tgz: MDS_final/test.f <==
      subroutine test(dist,rval,rbdwk,nbdwk2,nbdsrt2,nbdrnk2,
     &  iperm,notus1,nd1)
c
      implicit none
c
      integer notus1,nd1
c      
      real tottie(0:1),rval(0:nd1,0:notus1)
      real dist(0:notus1,0:notus1,0:1),rbdwk(notus1)
c
      integer nbdwk2(notus1),nbdsrt2(notus1),nbdrnk2(0:1,notus1,0:1)
      integer iperm(notus1)
c
      real obs,avg,dval,dev
c      
      integer iotus0,iotus1,id,ibnd,kflag,ier,ntie,ibndp
c
      write(*,*) 'Confidence Level Test'
      call distcal(rval,dist(0,0,1),notus1,nd1)
c---
cc      do 90 iotus0=0,notus1
cc        do 90 iotus1=0,notus1
cc          write(70,*) iotus0,iotus1,dist(iotus0,iotus1,1)
cc 90     continue
c---
cc      write(*,*) 'here1'
      call distcal1(notus1,dist(0,0,0))
cc      write(*,*) 'here2'
c
      do 100 iotus0=0,notus1
        do 105 id=0,1
          
        tottie(id)=0
        ibnd=1
        do 110 iotus1=0,notus1
          if (iotus1.ne.iotus0) then
            rbdwk(ibnd)=dist(iotus0,iotus1,id)
            nbdwk2(ibnd)=ibnd
            ibnd=ibnd+1
          end if  
 110    continue
c
        kflag=2
        call spsort(rbdwk,notus1,iperm,kflag,ier)
c
        ibnd=1
        do 120 iotus1=0,notus1
          if (iotus1.ne.iotus0) then
            nbdsrt2(ibnd)=nbdwk2(iperm(ibnd))
            ibnd=ibnd+1
          end if  
 120    continue
c
        ibnd=0
 130    continue
        ntie=0
 140      continue
            ntie=ntie+1
            ibnd=ibnd+1
            if (ibnd.eq.notus1) goto 160
          if (rbdwk(ibnd).eq.rbdwk(ibnd+1)) goto 140
 160      continue
c
          tottie(id)=tottie(id)+ntie**3-ntie
          do 150 ibndp=ibnd-ntie+1,ibnd
            nbdrnk2(0,nbdsrt2(ibndp),id)=ibnd-(ntie-1)
            nbdrnk2(1,nbdsrt2(ibndp),id)=ibnd
 150      continue
          if (ibnd.lt.notus1) goto 130
 105    continue
c
            obs=0
            do 170 ibnd=1,notus1
c---
cc              write(*,*)(nbdrnk2(0,ibnd,0)+nbdrnk2(1,ibnd,0))/2,
cc     &          (nbdrnk2(0,ibnd,1)+nbdrnk2(1,ibnd,1))/2
cc              read(*,*)
c---
              obs=obs
     &   +((nbdrnk2(0,ibnd,0)+nbdrnk2(1,ibnd,0))/2
     &    -(nbdrnk2(0,ibnd,1)+nbdrnk2(1,ibnd,1))/2)**2
c---
cc              write(*,*)      nbdrnk2(0,ibnd,0),nbdrnk2(1,ibnd,0),
cc     &    nbdrnk2(0,ibnd,1),nbdrnk2(1,ibnd,1)
cc           read(*,*)
c---
 170     continue
          avg=(notus1**3-notus1)/6.0-(tottie(0)+tottie(1))/12.0
          dval=sqrt((notus1-1)*(notus1*1.0d0*(notus1+1))**2/36.0
     &      *(1-tottie(0)/(notus1**3-notus1))
     &      *(1-tottie(1)/(notus1**3-notus1)))
        dev=(avg-obs)/dval
c
        if (dev.le.1.65) then
          write(*,*) iotus0, avg, obs, dval, dev, ' ** (> 0.05)'
        else if (dev.le.2.35) then
          write(*,*) iotus0, avg, obs, dval, dev, ' * (> 0.01)'
        else if (dev.le.2.58) then
          write(*,*) iotus0, avg, obs, dval, dev, ' (> 0.005)'
        else
          write(*,*) iotus0, avg, obs, dval, dev
          end if
 100  continue
c
      return
c
      end

==> nmds.1.2.3.tgz: MDS_final/test.f <==
      subroutine test(dist,rval,rbdwk,nbdwk2,nbdsrt2,nbdrnk2,
     &  avg,obs,dval,dev,iperm,notus,notus1,nd1)
c
      implicit none
c
      integer notus,notus1,nd1
c      
      real tottie(0:1),rval(0:nd1,0:notus1)
      real dist(0:notus1,0:notus1,0:1),rbdwk(notus1)
      real avg(notus),obs(notus),dval(notus),dev(notus)
c
      integer nbdwk2(notus1),nbdsrt2(notus1),nbdrnk2(0:1,notus1,0:1)
      integer iperm(notus)
c
      integer iotus0,iotus1,id,ibnd,kflag,ier,ntie,ibndp
c
      write(*,*) 'Confidence Level Test'
      call distcal(rval,dist(0,0,1),notus1,nd1)
c---
cc      do 90 iotus0=0,notus1
cc        do 90 iotus1=0,notus1
cc          write(70,*) iotus0,iotus1,dist(iotus0,iotus1,1)
cc 90     continue
c---
cc      write(*,*) 'here1'
      call distcal1(notus1,dist(0,0,0))
cc      write(*,*) 'here2'
c
      do 100 iotus0=0,notus1
        do 105 id=0,1
          
        tottie(id)=0
        ibnd=1
        do 110 iotus1=0,notus1
          if (iotus1.ne.iotus0) then
            rbdwk(ibnd)=dist(iotus0,iotus1,id)
            nbdwk2(ibnd)=ibnd
            ibnd=ibnd+1
          end if  
 110    continue
c
        kflag=2
        call spsort(rbdwk,notus1,iperm,kflag,ier)
c
        ibnd=1
        do 120 iotus1=0,notus1
          if (iotus1.ne.iotus0) then
            nbdsrt2(ibnd)=nbdwk2(iperm(ibnd))
            ibnd=ibnd+1
          end if  
 120    continue
c
        ibnd=0
 130    continue
        ntie=0
 140      continue
            ntie=ntie+1
            ibnd=ibnd+1
            if (ibnd.eq.notus1) goto 160
          if (rbdwk(ibnd).eq.rbdwk(ibnd+1)) goto 140
 160      continue
c
          tottie(id)=tottie(id)+ntie**3-ntie
          do 150 ibndp=ibnd-ntie+1,ibnd
            nbdrnk2(0,nbdsrt2(ibndp),id)=ibnd-(ntie-1)
            nbdrnk2(1,nbdsrt2(ibndp),id)=ibnd
 150      continue
          if (ibnd.lt.notus1) goto 130
 105    continue
c
            obs(iotus0+1)=0
            do 170 ibnd=1,notus1
c---
cc              write(*,*)(nbdrnk2(0,ibnd,0)+nbdrnk2(1,ibnd,0))/2,
cc     &          (nbdrnk2(0,ibnd,1)+nbdrnk2(1,ibnd,1))/2
cc              read(*,*)
c---
              obs(iotus0+1)=obs(iotus0+1)
     &   +((nbdrnk2(0,ibnd,0)+nbdrnk2(1,ibnd,0))/2
     &    -(nbdrnk2(0,ibnd,1)+nbdrnk2(1,ibnd,1))/2)**2
c---
cc              write(*,*)      nbdrnk2(0,ibnd,0),nbdrnk2(1,ibnd,0),
cc     &    nbdrnk2(0,ibnd,1),nbdrnk2(1,ibnd,1)
cc           read(*,*)
c---
 170     continue
         avg(iotus0+1)=(notus1**3-notus1)/6.0-(tottie(0)+tottie(1))/12.0
         dval(iotus0+1)=sqrt((notus1-1)*(notus1*1.0d0*(notus1+1))**2/36.0
     &      *(1-tottie(0)/(notus1**3-notus1))
     &      *(1-tottie(1)/(notus1**3-notus1)))
         dev(iotus0+1)=(avg(iotus0+1)-obs(iotus0+1))/dval(iotus0+1)
 100    continue
c
        kflag=-1
        call spsort(dev,notus,iperm,kflag,ier)
c
        do 180 iotus0=0,notus1
          iotus1=iperm(iotus0+1)
          if (dev(iotus1).le.1.65) then
            write(*,*) iotus1, avg(iotus1), obs(iotus1),
     &        dval(iotus1), dev(iotus1), ' ** (> 0.05)'
        else if (dev(iotus1).le.2.35) then
            write(*,*) iotus1, avg(iotus1), obs(iotus1),
     &        dval(iotus1), dev(iotus1), ' * (> 0.01)'
        else if (dev(iotus1).le.2.58) then
            write(*,*) iotus1, avg(iotus1), obs(iotus1),
     &        dval(iotus1), dev(iotus1), ' * (> 0.005)'
        else
            write(*,*) iotus1, avg(iotus1), obs(iotus1),
     &        dval(iotus1), dev(iotus1)
        end if
 180  continue
c
      return
c
      end
